internetradio2.0/songhistoryinc/irsonghistorydb.h
changeset 5 0930554dc389
parent 0 09774dfdd46b
child 8 3b03c28289e6
--- a/internetradio2.0/songhistoryinc/irsonghistorydb.h	Fri May 14 15:43:29 2010 +0300
+++ b/internetradio2.0/songhistoryinc/irsonghistorydb.h	Thu May 27 12:46:34 2010 +0300
@@ -81,25 +81,28 @@
 
 
 
-	/**
-	* Function : AddToSongHistoryDbL()
-	* adds the song history entry into data base
-	* @param various channel information 
-	*/
-	TBool AddToSongHistoryDbL( const TDesC& aSongName,
-								const TDesC& aArtistName, 
-								const TDesC& aChannelName, 
-								const TDesC& aChannelUrl,
-								RBuf& aDelSongName, 
-								RBuf& aDelArtistname, 
-								RBuf& aDelChannelName, 
-								RBuf& aDelChannelUrl,
-								TInt  aChannelType,
-								TInt aChannelId,
-								TInt aBitrate,
-								const TDesC& aChannelDesc,
-								const TDesC& aImageUrl,
-								const TDesC& aMusicFlag);
+    /**
+    * Function : AddToSongHistoryDbL()
+    * adds the song history entry into data base
+    * @param various channel information 
+    */
+    TBool AddToSongHistoryDbL( const TDesC& aSongName,
+                                const TDesC& aArtistName, 
+                                const TDesC& aChannelName, 
+                                const TDesC& aChannelUrl,
+                                RBuf& aDelSongName, 
+                                RBuf& aDelArtistname, 
+                                RBuf& aDelChannelName, 
+                                RBuf& aDelChannelUrl,
+                                TInt  aChannelType,
+                                TInt aChannelId,
+                                TInt aBitrate,
+                                const TDesC& aChannelDesc,
+                                const TDesC& aImageUrl,
+                                const TDesC& aGenreName,
+                                const TDesC& aCountryName,
+                                const TDesC& aLanguageName,
+                                const TDesC& aMusicFlag);
 	 /**
 	 * Function : AddToSongHistoryDb2L()
 	 * adds the song history entry into data base
@@ -183,6 +186,9 @@
     	                      const TDesC& aChannelName, 
 						      const TDesC& aChannelUrl,
 						      const TDesC& aImageUrl,
+                              const TDesC& aGenreName,
+                              const TDesC& aCountryName,
+                              const TDesC& aLanguageName,						      
 							  const TDesC& aMusicFlag);
 
     /*
@@ -192,10 +198,14 @@
                                 TInt aChannelType);
     
     /*
-     * delete a recorder by the index
+     * delete a recorder by the index, for station history database
      * */
     TInt DeleteOneHistory(TInt aIndex);
     
+    /*
+     * delete a recorder by the index, for songhistory database
+     * */
+    TInt DeleteOneSongHistory(TInt aIndex);
 
 private:
 
@@ -218,9 +228,9 @@
 	* ---------------------------------------------------------------------------
 	* SongHistoryTable
 	*---------------------------
 	*| SongName | ArtistName | ChannelName | ChannelUrl | ChannelType | ChannelId | Bitrate | ChannelDesc | ImageUrl
 	*---------------------------
-	*|EDbColText| EDbColText | EDbColText | EDbColText | EDbColUint8 | EDbColUint16 | EDbColUint16 | EDbColText | EDbColText
+	*|EDbColText| EDbColText | EDbColText  | EDbColText | EDbColUint8 | EDbColUint16 | EDbColUint16 | EDbColText  | EDbColText | EDbColText | EDbColText  | EDbColText   | EDbColText 
 	*----------------------------------------------------------------------------
 	*/
 	void CreateSongHistoryTablesL();
@@ -266,6 +276,11 @@
 	 */
 	TInt DeleteOneHistoryL(TInt aIndex);
 
+    /**
+     * to wrapper the delete leaving
+     */
+    TInt DeleteOneSongHistoryL(TInt aIndex);
+
 	/**
 	* Data-structure to hold unique channel info
 	*/
@@ -218,9 +228,9 @@
 	* SongHistoryTable
 	*---------------------------
-	*| SongName | ArtistName | ChannelName | ChannelUrl | ChannelType | ChannelId | Bitrate | ChannelDesc | ImageUrl
+	*| SongName | ArtistName | ChannelName | ChannelUrl | ChannelType | ChannelId    | Bitrate      | ChannelDesc | ImageUrl   | GenreName  | CountryName | LanguageName | MusicStatus
 	*---------------------------